@@ -10,14 +10,13 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from tests import BaseSessionTest, ClientHTTPStubber
 from botocore.stub import Stubber
+from tests import BaseSessionTest, ClientHTTPStubber
 
 
 class TestRDSPresignUrlInjection(BaseSessionTest):
-
     def setUp(self):
-        super(TestRDSPresignUrlInjection, self).setUp()
+        super().setUp()
         self.client = self.session.create_client('rds', 'us-west-2')
         self.http_stubber = ClientHTTPStubber(self.client)
 
@@ -29,7 +28,7 @@ class TestRDSPresignUrlInjection(BaseSessionTest):
         params = {
             'SourceDBSnapshotIdentifier': 'source-db',
             'TargetDBSnapshotIdentifier': 'target-db',
-            'SourceRegion': 'us-east-1'
+            'SourceRegion': 'us-east-1',
         }
         response_body = (
             b'<CopyDBSnapshotResponse>'
@@ -46,7 +45,7 @@ class TestRDSPresignUrlInjection(BaseSessionTest):
         params = {
             'SourceDBInstanceIdentifier': 'source-db',
             'DBInstanceIdentifier': 'target-db',
-            'SourceRegion': 'us-east-1'
+            'SourceRegion': 'us-east-1',
         }
         response_body = (
             b'<CreateDBInstanceReadReplicaResponse>'
@@ -73,7 +72,9 @@ class TestRDSPresignUrlInjection(BaseSessionTest):
         )
         self.http_stubber.add_response(body=response_body)
         with self.http_stubber:
-            self.client.start_db_instance_automated_backups_replication(**params)
+            self.client.start_db_instance_automated_backups_replication(
+                **params
+            )
             sent_request = self.http_stubber.requests[0]
             self.assert_presigned_url_injected_in_request(sent_request.body)
 
@@ -90,7 +91,8 @@ class TestRDS(BaseSessionTest):
         port = 3306
         username = 'mySQLUser'
         auth_token = self.client.generate_db_auth_token(
-            DBHostname=hostname, Port=port, DBUsername=username)
+            DBHostname=hostname, Port=port, DBUsername=username
+        )
 
         endpoint_url = 'host.us-east-1.rds.amazonaws.com:3306'
         self.assertIn(endpoint_url, auth_token)
