@@ -15,19 +15,16 @@ from contextlib import contextmanager
 
 import pytest
 
-from tests import unittest, ClientHTTPStubber
-
 from botocore import exceptions
-from botocore.exceptions import (
-    UnsupportedS3ControlArnError,
-    UnsupportedS3ControlConfigurationError,
-    InvalidHostLabelError,
-    ParamValidationError,
-)
-from botocore.session import Session
 from botocore.compat import urlsplit
 from botocore.config import Config
-
+from botocore.exceptions import (
+    InvalidHostLabelError,
+    ParamValidationError,
+    UnsupportedS3ControlArnError,
+)
+from botocore.session import Session
+from tests import ClientHTTPStubber, unittest
 
 ACCESSPOINT_ARN_TEST_CASES = [
     # Outpost accesspoint arn test cases
@@ -45,7 +42,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -58,7 +55,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -66,7 +63,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-cn:s3-outposts:cn-north-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -74,7 +71,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -87,7 +84,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -100,16 +97,16 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
+    },
+    {
+        'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
+        'region': 'fips-us-gov-east-1',
+        'config': {'s3': {'use_arn_region': True}},
+        'assertions': {
+            'exception': 'UnsupportedS3ControlArnError',
+        },
     },
-    # {
-    #    'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
-    #    'region': 'fips-us-gov-east-1',
-    #    'config': {'s3': {'use_arn_region': True}},
-    #    'assertions': {
-    #        'exception': 'UnsupportedS3ArnError',
-    #    }
-    # },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
         'region': 'us-gov-east-1-fips',
@@ -121,39 +118,44 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
         'config': {'s3': {'use_dualstack_endpoint': True}},
         'assertions': {
-            'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+            'signing_name': 's3-outposts',
+            'netloc': 's3-outposts.us-west-2.api.aws',
+            'headers': {
+                'x-amz-outpost-id': 'op-01234567890123456',
+                'x-amz-account-id': '123456789012',
+            },
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
         'config': {'s3': {'use_accelerate_endpoint': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:myaccesspoint',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
 ]
 
@@ -171,7 +173,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -184,7 +186,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -192,7 +194,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-cn:s3-outposts:cn-north-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -200,7 +202,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -213,7 +215,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -226,7 +228,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -234,7 +236,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -247,39 +249,44 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:bucket:mybucket',
         'region': 'us-west-2',
         'config': {'s3': {'use_dualstack_endpoint': True}},
         'assertions': {
-            'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+            'signing_name': 's3-outposts',
+            'netloc': 's3-outposts.us-west-2.api.aws',
+            'headers': {
+                'x-amz-outpost-id': 'op-01234567890123456',
+                'x-amz-account-id': '123456789012',
+            },
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:bucket',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:bucket',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
 ]
 
@@ -368,11 +375,9 @@ def _assert_test_case(test_case, client, stubber):
         exception_cls = getattr(exceptions, assertions['exception'])
         if exception_raised is None:
             raise RuntimeError(
-                'Expected exception "%s" was not raised' % exception_cls
+                f'Expected exception "{exception_cls}" was not raised'
             )
-        error_msg = (
-            'Expected exception "%s", got "%s"'
-        ) % (exception_cls, type(exception_raised))
+        error_msg = f'Expected exception "{exception_cls}", got "{type(exception_raised)}"'
         assert isinstance(exception_raised, exception_cls), error_msg
     else:
         assert len(stubber.requests) == 1
@@ -400,8 +405,11 @@ class TestS3ControlRedirection(unittest.TestCase):
     def test_outpost_id_redirection_dualstack(self):
         config = Config(s3={'use_dualstack_endpoint': True})
         self._bootstrap_client(config=config)
-        with self.assertRaises(UnsupportedS3ControlConfigurationError):
+        self.stubber.add_response()
+        with self.stubber:
             self.client.create_bucket(Bucket='foo', OutpostId='op-123')
+        _assert_netloc(self.stubber, 's3-outposts.us-west-2.api.aws')
+        _assert_header(self.stubber, 'x-amz-outpost-id', 'op-123')
 
     def test_outpost_id_redirection_create_bucket(self):
         self.stubber.add_response()
