@@ -236,7 +236,10 @@ class SessionTest(BaseSessionTest):
 
     def test_emit_delegates_to_emitter(self):
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         self.session.register('foo', handler)
         self.session.emit('foo')
         self.assertEqual(len(calls), 1)
@@ -248,7 +251,10 @@ class SessionTest(BaseSessionTest):
             session_vars=self.env_vars, event_hooks=events
         )
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         events.register('foo', handler)
 
         session.emit('foo')
@@ -283,7 +289,10 @@ class SessionTest(BaseSessionTest):
 
     def test_register_with_unique_id(self):
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         self.session.register('foo', handler, unique_id='bar')
         self.session.emit('foo')
         self.assertEqual(calls[0]['event_name'], 'foo')
@@ -723,8 +732,8 @@ class TestCreateClient(BaseSessionTest):
             f.write('[default]\n')
             f.write(
                 'foo_api_versions =\n'
-                '    myservice = %s\n' % config_api_version
-            )
+                f'    myservice = {config_api_version}\n'
+            )  # fmt: skip
             f.flush()
 
             self.session.create_client('myservice', 'us-west-2')
@@ -746,7 +755,7 @@ class TestCreateClient(BaseSessionTest):
                 f'foo_api_versions =\n'
                 f'    myservice = {config_api_version}\n'
                 f'    myservice2 = {second_config_api_version}\n'
-            )
+            )  # fmt: skip
             f.flush()
 
             self.session.create_client('myservice', 'us-west-2')
@@ -774,8 +783,8 @@ class TestCreateClient(BaseSessionTest):
             f.write('[default]\n')
             f.write(
                 'foo_api_versions =\n'
-                '    myservice = %s\n' % config_api_version
-            )
+                f'    myservice = {config_api_version}\n'
+            )  # fmt: skip
             f.flush()
 
             self.session.create_client(
@@ -842,14 +851,20 @@ class TestComponentLocator(unittest.TestCase):
 
     def test_can_lazy_register_a_component(self):
         component = object()
-        lazy = lambda: component
+
+        def lazy():
+            return component
+
         self.components.lazy_register_component('foo', lazy)
         self.assertIs(self.components.get_component('foo'), component)
 
     def test_latest_registration_wins_even_if_lazy(self):
         first = object()
         second = object()
-        lazy_second = lambda: second
+
+        def lazy_second():
+            return second
+
         self.components.register_component('foo', first)
         self.components.lazy_register_component('foo', lazy_second)
         self.assertIs(self.components.get_component('foo'), second)
@@ -857,7 +872,10 @@ class TestComponentLocator(unittest.TestCase):
     def test_latest_registration_overrides_lazy(self):
         first = object()
         second = object()
-        lazy_first = lambda: first
+
+        def lazy_first():
+            return first
+
         self.components.lazy_register_component('foo', lazy_first)
         self.components.register_component('foo', second)
         self.assertIs(self.components.get_component('foo'), second)
